waitpid_blocking

Function waitpid_blocking 

pub fn waitpid_blocking(pid: isize, status: &mut i32) -> Result<usize>
Wait for a child process, automatically retrying on EINTR.

This is the recommended wrapper for blocking waits. It calls waitpid in a loop and yields the CPU between retries when the kernel interrupts the wait with EINTR.