pub struct MapFlags(<MapFlags as PublicFlags>::Internal);Expand description
Memory mapping flags for SYS_MMAP.
These are not POSIX MAP_* values. The kernel uses its own
bit layout for efficiency.
Tuple Fields
0: <MapFlags as PublicFlags>::InternalImplementations
Sourceimpl MapFlags
impl MapFlags
Sourcepub const MAP_SHARED: MapFlags
pub const MAP_SHARED: MapFlags
Shared mapping: writes are visible to other processes mapping the same region.
Sourcepub const MAP_PRIVATE: MapFlags
pub const MAP_PRIVATE: MapFlags
Private mapping: copy-on-write semantics.
Sourcepub const MAP_FIXED: MapFlags
pub const MAP_FIXED: MapFlags
Fixed mapping: place at the exact address specified (may overwrite existing mappings).
Sourcepub const MAP_ANONYMOUS: MapFlags
pub const MAP_ANONYMOUS: MapFlags
Anonymous mapping: not backed by a file (requires MAP_PRIVATE).
Sourcepub const MAP_NORESERVE: MapFlags
pub const MAP_NORESERVE: MapFlags
Do not reserve swap space for this mapping.
Sourcepub const MAP_POPULATE: MapFlags
pub const MAP_POPULATE: MapFlags
Populate pages on demand (prefault all pages).
Sourcepub const MAP_LOCKED: MapFlags
pub const MAP_LOCKED: MapFlags
Lock the mapping in memory (cannot be swapped out).
Sourcepub const MAP_GROWSDOWN: MapFlags
pub const MAP_GROWSDOWN: MapFlags
Automatically expand the mapping downward (stack growth).
Sourceimpl MapFlags
impl MapFlags
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<MapFlags>
pub const fn from_bits(bits: u32) -> Option<MapFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> MapFlags
pub const fn from_bits_truncate(bits: u32) -> MapFlags
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> MapFlags
pub const fn from_bits_retain(bits: u32) -> MapFlags
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<MapFlags>
pub fn from_name(name: &str) -> Option<MapFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: MapFlags) -> bool
pub const fn intersects(&self, other: MapFlags) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: MapFlags) -> bool
pub const fn contains(&self, other: MapFlags) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: MapFlags)
pub fn remove(&mut self, other: MapFlags)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: MapFlags)
pub fn toggle(&mut self, other: MapFlags)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: MapFlags, value: bool)
pub fn set(&mut self, other: MapFlags, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: MapFlags) -> MapFlags
pub const fn intersection(self, other: MapFlags) -> MapFlags
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: MapFlags) -> MapFlags
pub const fn union(self, other: MapFlags) -> MapFlags
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: MapFlags) -> MapFlags
pub const fn difference(self, other: MapFlags) -> MapFlags
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: MapFlags) -> MapFlags
pub const fn symmetric_difference(self, other: MapFlags) -> MapFlags
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> MapFlags
pub const fn complement(self) -> MapFlags
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl MapFlags
impl MapFlags
Sourcepub const fn iter(&self) -> Iter<MapFlags>
pub const fn iter(&self) -> Iter<MapFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<MapFlags>
pub const fn iter_names(&self) -> IterNames<MapFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.